Struct google_binaryauthorization1::api::PkixPublicKey [−][src]
pub struct PkixPublicKey {
pub public_key_pem: Option<String>,
pub signature_algorithm: Option<String>,
}Expand description
A public key in the PkixPublicKey format (see https://tools.ietf.org/html/rfc5280#section-4.1.2.7 for details). Public keys of this type are typically textually encoded using the PEM format.
This type is not used in any activity, and only used as part of another schema.
Fields
public_key_pem: Option<String>A PEM-encoded public key, as described in https://tools.ietf.org/html/rfc7468#section-13
signature_algorithm: Option<String>The signature algorithm used to verify a message against a signature using this key. These signature algorithm must match the structure and any object identifiers encoded in public_key_pem (i.e. this algorithm must match that of the public key).