Struct google_binaryauthorization1::api::UserOwnedGrafeasNote [−][src]
pub struct UserOwnedGrafeasNote {
pub delegation_service_account_email: Option<String>,
pub note_reference: Option<String>,
pub public_keys: Option<Vec<AttestorPublicKey>>,
}Expand description
An user owned Grafeas note references a Grafeas Attestation.Authority Note created by the user.
This type is not used in any activity, and only used as part of another schema.
Fields
delegation_service_account_email: Option<String>Output only. This field will contain the service account email address that this Attestor will use as the principal when querying Container Analysis. Attestor administrators must grant this service account the IAM role needed to read attestations from the note_reference in Container Analysis (containeranalysis.notes.occurrences.viewer). This email address is fixed for the lifetime of the Attestor, but callers should not make any other assumptions about the service account email; future versions may use an email based on a different naming pattern.
note_reference: Option<String>Required. The Grafeas resource name of a Attestation.Authority Note, created by the user, in the format: projects/*/notes/*. This field may not be updated. An attestation by this attestor is stored as a Grafeas Attestation.Authority Occurrence that names a container image and that links to this Note. Grafeas is an external dependency.
public_keys: Option<Vec<AttestorPublicKey>>Optional. Public keys that verify attestations signed by this attestor. This field may be updated. If this field is non-empty, one of the specified public keys must verify that an attestation was signed by this attestor for the image specified in the admission request. If this field is empty, this attestor always returns that no valid attestations exist.